@@ -44,8 +44,6 @@ def bulk_sync(new_models, key_fields, filters, batch_size=None, fields=None, ski
             old_obj = obj_dict.pop(get_key(new_obj), None)
             if old_obj is None:
                 # This is a new object, so create it.
-                # Make sure the primary key field is clear.
-                new_obj.pk = None
                 new_objs.append(new_obj)
             else:
                 new_obj.id = old_obj.id
@@ -109,8 +107,6 @@ def bulk_compare(old_models, new_models, key_fields, ignore_fields=None):
         old_obj = old_obj_dict.pop(get_key(new_obj), None)
         if old_obj is None:
             # This is a new object, so create it.
-            # Make sure the primary key field is clear.
-            new_obj.pk = None
             new_objs.append(new_obj)
         else:
             new_obj.id = old_obj.id
